=== modified file 'tests/CMakeLists.txt'
--- tests/CMakeLists.txt	2012-04-03 12:36:46 +0000
+++ tests/CMakeLists.txt	2012-04-04 14:33:07 +0000
@@ -252,6 +252,8 @@
        GMOCK_LIB AND
        GMOCK_MAIN_LIB)
 
+add_subdirectory (test-gesture-engine)
+
 #
 # check target
 #
@@ -261,21 +263,25 @@
 set (GTEST_TEST_COMMAND ./test-gtest)
 set (GTEST_TEST_COMMAND_XLESS ./test-gtest-xless)
 set (GTEST_TEST_COMMAND_DBUS dbus-test-runner --task ./test-gtest-service --task ./test-gtest-dbus)
+set (GTEST_TEST_COMMAND_GESTURE_ENGINE ./test-gesture-engine/test-gesture-engine)
 
 set (TEST_COMMAND
      gtester --verbose -k --g-fatal-warnings -o=${TEST_RESULT_XML} ./test-unit
   && ${GTEST_TEST_COMMAND}
   && ${GTEST_TEST_COMMAND_XLESS}
-  && ${GTEST_TEST_COMMAND_DBUS})
+  && ${GTEST_TEST_COMMAND_GESTURE_ENGINE}
+  && ${GTEST_TEST_COMMAND_DBUS}
+    )
 
 set (TEST_COMMAND_HEADLESS
      ${GTEST_TEST_COMMAND_XLESS}
+  && ${GTEST_TEST_COMMAND_GESTURE_ENGINE}
   #&& ${GTEST_TEST_COMMAND_DBUS}
   && echo "Warning, DBus test cases are disabled!!")
 
 if (GTEST_SRC_DIR)
-  add_custom_target (check COMMAND  ${TEST_COMMAND} DEPENDS test-unit test-gtest test-gtest-xless test-gtest-dbus)
-  add_custom_target (check-headless COMMAND ${TEST_COMMAND_HEADLESS} DEPENDS test-gtest-xless test-gtest-dbus)
+  add_custom_target (check COMMAND  ${TEST_COMMAND} DEPENDS test-unit test-gtest test-gtest-xless test-gtest-dbus test-gesture-engine)
+  add_custom_target (check-headless COMMAND ${TEST_COMMAND_HEADLESS} DEPENDS test-gtest-xless test-gtest-dbus test-gesture-engine)
   add_custom_target (check-report COMMAND ${TEST_UNIT_COMMAND} && gtester-report ${TEST_RESULT_XML} > ${TEST_RESULT_HTML})
   add_custom_target (gcheck COMMAND  ${DBUS_TEST_COMMAND} DEPENDS test-gtest test-gtest-xless)
 else (GTEST_SRC_DIR)

=== added directory 'tests/test-gesture-engine'
=== added file 'tests/test-gesture-engine/CMakeLists.txt'
--- tests/test-gesture-engine/CMakeLists.txt	1970-01-01 00:00:00 +0000
+++ tests/test-gesture-engine/CMakeLists.txt	2012-04-04 14:33:07 +0000
@@ -0,0 +1,40 @@
+if (GTEST_SRC_DIR)
+  set(UNITY_SRC ${CMAKE_SOURCE_DIR}/plugins/unityshell/src)
+
+  add_custom_command(OUTPUT GestureEngine.cpp GestureEngine.h UBusMessages.h
+                     COMMAND cp ${UNITY_SRC}/GestureEngine.cpp ${UNITY_SRC}/GestureEngine.h ${UNITY_SRC}/UBusMessages.h ${CMAKE_CURRENT_BINARY_DIR}
+                     COMMAND sed -f ${CMAKE_CURRENT_SOURCE_DIR}/sed_script ${UNITY_SRC}/GestureEngine.cpp > ${CMAKE_CURRENT_BINARY_DIR}/GestureEngine.cpp
+                     COMMAND sed -f ${CMAKE_CURRENT_SOURCE_DIR}/sed_script ${UNITY_SRC}/GestureEngine.h > ${CMAKE_CURRENT_BINARY_DIR}/GestureEngine.h
+                     DEPENDS ${UNITY_SRC}/GestureEngine.cpp ${UNITY_SRC}/GestureEngine.h ${UNITY_SRC}/UBusMessages.h
+                     COMMENT "Copying GestureEngine source.")
+
+  # Clean-up includes and definitions made in ../CmakeLists.txt
+  remove_definitions(${CFLAGS})
+  set_directory_properties(PROPERTY INCLUDE_DIRECTORIES "")
+  # And make our own
+  pkg_check_modules (TEST_GESTURE_ENGINE_DEPS REQUIRED QUIET "${UNITY_PLUGIN_DEPS}")
+  set(TEST_GESTURE_ENGINE_CFLAGS
+      "-g"
+      "-I${CMAKE_CURRENT_SOURCE_DIR}"
+      "-I${CMAKE_CURRENT_BINARY_DIR}"
+      ${TEST_GESTURE_ENGINE_DEPS_CFLAGS}
+     )
+  add_definitions(${TEST_GESTURE_ENGINE_CFLAGS})
+
+  pkg_check_modules (COMPIZ REQUIRED QUIET compiz)
+  link_directories (${COMPIZ_LIBDIR})
+
+  add_executable(test-gesture-engine
+                 test_gesture_engine.cpp
+                 X11_mock.cpp
+                 GestureEngine.cpp
+                 PluginAdapterMock.cpp
+                 GeisAdapterMock.cpp
+                 ubus-server-mock.cpp
+                )
+  target_link_libraries(test-gesture-engine gtest ${TEST_GESTURE_ENGINE_DEPS_LIBRARIES} -lcompiz_core)
+  add_test(UnityGTestGestureEngine test-gesture-engine)
+  add_dependencies(test-gesture-engine gtest)
+
+  add_custom_target (check-gesture-engine COMMAND ./test-gesture-engine DEPENDS test-gesture-engine)
+endif (GTEST_SRC_DIR)

=== added file 'tests/test-gesture-engine/GeisAdapterMock.cpp'
--- tests/test-gesture-engine/GeisAdapterMock.cpp	1970-01-01 00:00:00 +0000
+++ tests/test-gesture-engine/GeisAdapterMock.cpp	2012-04-04 14:33:07 +0000
@@ -0,0 +1,30 @@
+/*
+ * Copyright 2012 Canonical Ltd.
+ *
+ * This program is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License version 3, as published
+ * by the  Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranties of
+ * MERCHANTABILITY, SATISFACTORY QUALITY or FITNESS FOR A PARTICULAR
+ * PURPOSE.  See the GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * version 3 along with this program.  If not, see
+ * <http://www.gnu.org/licenses/>
+ *
+ * Authored by: Daniel d'Andrada <daniel.dandrada@canonical.com>
+ *
+ */
+
+#include "GeisAdapterMock.h"
+
+GeisAdapterMock *GeisAdapterMock::_default = 0;
+
+GeisAdapterMock* GeisAdapterMock::Default() {
+  if (!_default) {
+    _default = new GeisAdapterMock;
+  }
+  return _default;
+}

=== added file 'tests/test-gesture-engine/GeisAdapterMock.h'
--- tests/test-gesture-engine/GeisAdapterMock.h	1970-01-01 00:00:00 +0000
+++ tests/test-gesture-engine/GeisAdapterMock.h	2012-04-04 14:33:07 +0000
@@ -0,0 +1,148 @@
+/*
+ * Copyright 2012 Canonical Ltd.
+ *
+ * This program is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License version 3, as published
+ * by the  Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranties of
+ * MERCHANTABILITY, SATISFACTORY QUALITY or FITNESS FOR A PARTICULAR
+ * PURPOSE.  See the GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * version 3 along with this program.  If not, see
+ * <http://www.gnu.org/licenses/>
+ *
+ * Authored by: Daniel d'Andrada <daniel.dandrada@canonical.com>
+ *
+ */
+
+#ifndef GEISADAPTER_MOCK_H
+#define GEISADAPTER_MOCK_H
+
+#include <sigc++/sigc++.h>
+#include <X11/Xlib.h>
+
+class GeisAdapterMock : public sigc::trackable
+{
+public:
+  static GeisAdapterMock* Default();
+
+  ~GeisAdapterMock() {}
+
+  typedef struct _GeisTapData
+  {
+    int id;
+    int device_id;
+    Window window;
+    int touches;
+    int timestamp;
+    float focus_x;
+    float focus_y;
+    int tap_length_ms;
+    float position_x;
+    float position_y;
+    float bound_x1;
+    float bound_y1;
+    float bound_x2;
+    float bound_y2;
+  } GeisTapData;
+
+  typedef struct _GeisDragData
+  {
+    int id;
+    int device_id;
+    Window window;
+    int touches;
+    int timestamp;
+    float focus_x;
+    float focus_y;
+    float delta_x;
+    float delta_y;
+    float velocity_x;
+    float velocity_y;
+    float position_x;
+    float position_y;
+    float bound_x1;
+    float bound_y1;
+    float bound_x2;
+    float bound_y2;
+  } GeisDragData;
+
+  typedef struct _GeisRotateData
+  {
+    int id;
+    int device_id;
+    Window window;
+    int touches;
+    int timestamp;
+    float focus_x;
+    float focus_y;
+    float angle;
+    float angle_delta;
+    float angle_velocity;
+    float bound_x1;
+    float bound_y1;
+    float bound_x2;
+    float bound_y2;
+  } GeisRotateData;
+
+  typedef struct _GeisPinchData
+  {
+    int id;
+    int device_id;
+    Window window;
+    int touches;
+    int timestamp;
+    float focus_x;
+    float focus_y;
+    float radius;
+    float radius_delta;
+    float radius_velocity;
+    float bound_x1;
+    float bound_y1;
+    float bound_x2;
+    float bound_y2;
+  } GeisPinchData;
+
+  typedef struct _GeisTouchData
+  {
+    int id;
+    int device_id;
+    Window window;
+    int touches;
+    int timestamp;
+    float focus_x;
+    float focus_y;
+    float bound_x1;
+    float bound_y1;
+    float bound_x2;
+    float bound_y2;
+  } GeisTouchData;
+
+  sigc::signal<void, GeisTapData*> tap;
+
+  sigc::signal<void, GeisDragData*> drag_start;
+  sigc::signal<void, GeisDragData*> drag_update;
+  sigc::signal<void, GeisDragData*> drag_finish;
+
+  sigc::signal<void, GeisRotateData*> rotate_start;
+  sigc::signal<void, GeisRotateData*> rotate_update;
+  sigc::signal<void, GeisRotateData*> rotate_finish;
+
+  sigc::signal<void, GeisPinchData*> pinch_start;
+  sigc::signal<void, GeisPinchData*> pinch_update;
+  sigc::signal<void, GeisPinchData*> pinch_finish;
+
+  sigc::signal<void, GeisTouchData*> touch_start;
+  sigc::signal<void, GeisTouchData*> touch_update;
+  sigc::signal<void, GeisTouchData*> touch_finish;
+
+private:
+  GeisAdapterMock() {}
+
+  static GeisAdapterMock* _default;
+
+};
+#endif

=== added file 'tests/test-gesture-engine/PluginAdapterMock.cpp'
--- tests/test-gesture-engine/PluginAdapterMock.cpp	1970-01-01 00:00:00 +0000
+++ tests/test-gesture-engine/PluginAdapterMock.cpp	2012-04-04 14:33:07 +0000
@@ -0,0 +1,33 @@
+/*
+ * Copyright 2012 Canonical Ltd.
+ *
+ * This program is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License version 3, as published
+ * by the  Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranties of
+ * MERCHANTABILITY, SATISFACTORY QUALITY or FITNESS FOR A PARTICULAR
+ * PURPOSE.  See the GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * version 3 along with this program.  If not, see
+ * <http://www.gnu.org/licenses/>
+ *
+ * Authored by: Daniel d'Andrada <daniel.dandrada@canonical.com>
+ *
+ */
+
+#include "PluginAdapterMock.h"
+
+PluginAdapterMock *PluginAdapterMock::_default = 0;
+
+PluginAdapterMock *PluginAdapterMock::Default() {
+  if (!_default) {
+    _default = new PluginAdapterMock;
+  }
+  return _default;
+}
+
+void PluginAdapterMock::ShowGrabHandles(CompWindowMock* window, bool use_timer) {
+}

=== added file 'tests/test-gesture-engine/PluginAdapterMock.h'
--- tests/test-gesture-engine/PluginAdapterMock.h	1970-01-01 00:00:00 +0000
+++ tests/test-gesture-engine/PluginAdapterMock.h	2012-04-04 14:33:07 +0000
@@ -0,0 +1,37 @@
+/*
+ * Copyright 2012 Canonical Ltd.
+ *
+ * This program is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License version 3, as published
+ * by the  Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranties of
+ * MERCHANTABILITY, SATISFACTORY QUALITY or FITNESS FOR A PARTICULAR
+ * PURPOSE.  See the GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * version 3 along with this program.  If not, see
+ * <http://www.gnu.org/licenses/>
+ *
+ * Authored by: Daniel d'Andrada <daniel.dandrada@canonical.com>
+ *
+ */
+
+#ifndef PLUGINADAPTER_MOCK_H
+#define PLUGINADAPTER_MOCK_H
+
+#include <compiz_mock/core/core.h>
+
+class PluginAdapterMock {
+public:
+  static PluginAdapterMock *Default();
+
+  void ShowGrabHandles(CompWindowMock* window, bool use_timer);
+
+private:
+  PluginAdapterMock() {}
+  static PluginAdapterMock* _default;
+};
+
+#endif

=== added file 'tests/test-gesture-engine/X11_mock.cpp'
--- tests/test-gesture-engine/X11_mock.cpp	1970-01-01 00:00:00 +0000
+++ tests/test-gesture-engine/X11_mock.cpp	2012-04-04 14:33:07 +0000
@@ -0,0 +1,40 @@
+/*
+ * Copyright 2012 Canonical Ltd.
+ *
+ * This program is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License version 3, as published
+ * by the  Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranties of
+ * MERCHANTABILITY, SATISFACTORY QUALITY or FITNESS FOR A PARTICULAR
+ * PURPOSE.  See the GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * version 3 along with this program.  If not, see
+ * <http://www.gnu.org/licenses/>
+ *
+ * Authored by: Daniel d'Andrada <daniel.dandrada@canonical.com>
+ *
+ */
+
+#include <X11/Xlib.h>
+
+Cursor XCreateFontCursorMock(Display * /*display*/, unsigned int /*shape*/) {
+    return 1;
+}
+
+int XFreeCursorMock(Display * /*display*/, Cursor /*cursor*/) {
+    return 1;
+}
+
+int XSyncMock(Display *display, Bool discard) {
+  return 1;
+}
+
+int XWarpPointerMock(Display *display, Window src_w, Window dest_w,
+                     int src_x, int src_y,
+                     unsigned int src_width, unsigned int src_height,
+                     int dest_x, int dest_y) {
+  return 1;
+}

=== added file 'tests/test-gesture-engine/X11_mock.h'
--- tests/test-gesture-engine/X11_mock.h	1970-01-01 00:00:00 +0000
+++ tests/test-gesture-engine/X11_mock.h	2012-04-04 14:33:07 +0000
@@ -0,0 +1,37 @@
+/*
+ * Copyright 2012 Canonical Ltd.
+ *
+ * This program is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License version 3, as published
+ * by the  Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranties of
+ * MERCHANTABILITY, SATISFACTORY QUALITY or FITNESS FOR A PARTICULAR
+ * PURPOSE.  See the GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * version 3 along with this program.  If not, see
+ * <http://www.gnu.org/licenses/>
+ *
+ * Authored by: Daniel d'Andrada <daniel.dandrada@canonical.com>
+ *
+ */
+
+#ifndef X11_MOCK_H
+#define X11_MOCK_H
+
+#include <X11/Xlib.h>
+
+Cursor XCreateFontCursorMock(Display *display, unsigned int shape);
+
+int XFreeCursorMock(Display *display, Cursor cursor);
+
+int XSyncMock(Display *display, Bool discard);
+
+int XWarpPointerMock(Display *display, Window src_w, Window dest_w,
+                     int src_x, int src_y,
+                     unsigned int src_width, unsigned int src_height,
+                     int dest_x, int dest_y);
+
+#endif // X11_MOCK_H

=== added directory 'tests/test-gesture-engine/compiz_mock'
=== added directory 'tests/test-gesture-engine/compiz_mock/core'
=== added file 'tests/test-gesture-engine/compiz_mock/core/core.h'
--- tests/test-gesture-engine/compiz_mock/core/core.h	1970-01-01 00:00:00 +0000
+++ tests/test-gesture-engine/compiz_mock/core/core.h	2012-04-04 14:33:07 +0000
@@ -0,0 +1,29 @@
+/*
+ * Copyright 2012 Canonical Ltd.
+ *
+ * This program is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License version 3, as published
+ * by the  Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranties of
+ * MERCHANTABILITY, SATISFACTORY QUALITY or FITNESS FOR A PARTICULAR
+ * PURPOSE.  See the GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * version 3 along with this program.  If not, see
+ * <http://www.gnu.org/licenses/>
+ *
+ * Authored by: Daniel d'Andrada <daniel.dandrada@canonical.com>
+ *
+ */
+
+#ifndef COMPIZ_CORE_MOCK_H
+#define COMPIZ_CORE_MOCK_H
+
+#include <X11_mock.h>
+
+#include <compiz_mock/core/window.h>
+#include <compiz_mock/core/screen.h>
+
+#endif

=== added file 'tests/test-gesture-engine/compiz_mock/core/screen.h'
--- tests/test-gesture-engine/compiz_mock/core/screen.h	1970-01-01 00:00:00 +0000
+++ tests/test-gesture-engine/compiz_mock/core/screen.h	2012-04-04 14:33:07 +0000
@@ -0,0 +1,68 @@
+/*
+ * Copyright 2012 Canonical Ltd.
+ *
+ * This program is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License version 3, as published
+ * by the  Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranties of
+ * MERCHANTABILITY, SATISFACTORY QUALITY or FITNESS FOR A PARTICULAR
+ * PURPOSE.  See the GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * version 3 along with this program.  If not, see
+ * <http://www.gnu.org/licenses/>
+ *
+ * Authored by: Daniel d'Andrada <daniel.dandrada@canonical.com>
+ *
+ */
+
+#ifndef COMPIZ_SCREEN_MOCK_H
+#define COMPIZ_SCREEN_MOCK_H
+
+#include <X11/Xlib.h>
+#include <vector>
+
+// The real CompScreen
+#include <core/screen.h>
+
+typedef std::vector<CompWindowMock*> CompWindowMockVector;
+
+class CompScreenMock {
+public:
+  typedef int GrabHandle;
+
+  int width() const {return _width;}
+  int height() const {return _height;}
+
+  Display *dpy() {return _dpy;}
+
+  const CompWindowMockVector & clientList(bool stackingOrder = true) {
+    if (stackingOrder)
+      return _client_list_stacking;
+    else
+      return _client_list;
+  }
+
+  Window root() {return _root;}
+
+  GrabHandle pushGrab(Cursor cursor, const char *name) {return 0;}
+  void removeGrab(GrabHandle handle, CompPoint *restorePointer) {}
+
+  Cursor invisibleCursor() {return 1;}
+
+  int _width;
+  int _height;
+  Display *_dpy;
+  CompWindowMockVector _client_list;
+  CompWindowMockVector _client_list_stacking;
+  Window _root;
+};
+
+extern CompScreenMock *screen_mock;
+extern int pointerX_mock;
+extern int pointerY_mock;
+
+#endif
+

=== added file 'tests/test-gesture-engine/compiz_mock/core/window.h'
--- tests/test-gesture-engine/compiz_mock/core/window.h	1970-01-01 00:00:00 +0000
+++ tests/test-gesture-engine/compiz_mock/core/window.h	2012-04-04 14:33:07 +0000
@@ -0,0 +1,66 @@
+/*
+ * Copyright 2012 Canonical Ltd.
+ *
+ * This program is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License version 3, as published
+ * by the  Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranties of
+ * MERCHANTABILITY, SATISFACTORY QUALITY or FITNESS FOR A PARTICULAR
+ * PURPOSE.  See the GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * version 3 along with this program.  If not, see
+ * <http://www.gnu.org/licenses/>
+ *
+ * Authored by: Daniel d'Andrada <daniel.dandrada@canonical.com>
+ *
+ */
+
+#ifndef COMPIZ_WINDOW_MOCK_H
+#define COMPIZ_WINDOW_MOCK_H
+
+/* The real CompWindow */
+#include <core/window.h>
+
+class CompWindowMock {
+public:
+  CompWindowMock() : _moved(false) {}
+
+  int x() const {return _geometry.x();}
+  int y() const {return _geometry.y();}
+  int width() const {return _geometry.width() + (_geometry.border()*2);}
+  int height() const {return _geometry.height() + (_geometry.border()*2);}
+
+  void move(int dx, int dy, bool immediate = true) {
+    _moved = true;
+    _movement_x = dx;
+    _movement_y = dy;
+  }
+
+  unsigned int actions () {return _actions;}
+
+  void maximize(int state) {}
+
+  /* OBS: I wonder why it returns a reference */
+  unsigned int &state() {return _state;}
+
+  void grabNotify(int x, int y, unsigned int state, unsigned int mask) {}
+  void ungrabNotify() {}
+
+  void syncPosition() {}
+
+  compiz::window::Geometry &serverGeometry() {return _serverGeometry;}
+
+  unsigned int _actions;
+  unsigned int _state;
+  compiz::window::Geometry _serverGeometry;
+  compiz::window::Geometry _geometry;
+
+  bool _moved;
+  int _movement_x;
+  int _movement_y;
+};
+
+#endif

=== added file 'tests/test-gesture-engine/sed_script'
--- tests/test-gesture-engine/sed_script	1970-01-01 00:00:00 +0000
+++ tests/test-gesture-engine/sed_script	2012-04-04 14:33:07 +0000
@@ -0,0 +1,14 @@
+s|<core/core.h>|<compiz_mock/core/core.h>|
+s|\<CompScreen\>|CompScreenMock|g
+s|\<CompWindow\>|CompWindowMock|g
+s|\<CompWindowVector\>|CompWindowMockVector|g
+s|\<screen\>|screen_mock|g
+s|\<pointerX\>|pointerX_mock|g
+s|\<pointerY\>|pointerY_mock|g
+s|\<XSync\>|XSyncMock|g
+s|\<XWarpPointer\>|XWarpPointerMock|g
+s|\<XFreeCursor\>|XFreeCursorMock|g
+s|\<XCreateFontCursor\>|XCreateFontCursorMock|g
+s|\<GeisAdapter\>|GeisAdapterMock|g
+s|\<PluginAdapter\>|PluginAdapterMock|g
+s|\<ubus-server.h\>|ubus-server-mock.h|g

=== added file 'tests/test-gesture-engine/test_gesture_engine.cpp'
--- tests/test-gesture-engine/test_gesture_engine.cpp	1970-01-01 00:00:00 +0000
+++ tests/test-gesture-engine/test_gesture_engine.cpp	2012-04-04 14:33:07 +0000
@@ -0,0 +1,42 @@
+/*
+ * Copyright 2012 Canonical Ltd.
+ *
+ * This program is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License version 3, as published
+ * by the  Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranties of
+ * MERCHANTABILITY, SATISFACTORY QUALITY or FITNESS FOR A PARTICULAR
+ * PURPOSE.  See the GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * version 3 along with this program.  If not, see
+ * <http://www.gnu.org/licenses/>
+ *
+ * Authored by: Daniel d'Andrada <daniel.dandrada@canonical.com>
+ *
+ */
+
+#include <gtest/gtest.h>
+#include <compiz_mock/core/core.h>
+#include "GestureEngine.h"
+
+CompScreenMock concrete_screen_mock;
+CompScreenMock *screen_mock = &concrete_screen_mock;
+int pointerX_mock = 0;
+int pointerY_mock = 0;
+
+TEST(GestureEngineTest, Foo)
+{
+  GestureEngine gestureEngine(screen_mock);
+}
+
+int main(int argc, char** argv)
+{
+  ::testing::InitGoogleTest(&argc, argv);
+
+  int ret = RUN_ALL_TESTS();
+
+  return ret;
+}

=== added file 'tests/test-gesture-engine/ubus-server-mock.cpp'
--- tests/test-gesture-engine/ubus-server-mock.cpp	1970-01-01 00:00:00 +0000
+++ tests/test-gesture-engine/ubus-server-mock.cpp	2012-04-04 14:33:07 +0000
@@ -0,0 +1,32 @@
+/*
+ * Copyright 2012 Canonical Ltd.
+ *
+ * This program is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License version 3, as published
+ * by the  Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranties of
+ * MERCHANTABILITY, SATISFACTORY QUALITY or FITNESS FOR A PARTICULAR
+ * PURPOSE.  See the GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * version 3 along with this program.  If not, see
+ * <http://www.gnu.org/licenses/>
+ *
+ * Authored by: Daniel d'Andrada <daniel.dandrada@canonical.com>
+ *
+ */
+
+#include <ubus-server-mock.h>
+
+UBusServer default_server;
+
+UBusServer* ubus_server_get_default() {
+  return &default_server;
+}
+
+void ubus_server_send_message(UBusServer*   server,
+                              const gchar*  message,
+                              GVariant*     data) {
+}

=== added file 'tests/test-gesture-engine/ubus-server-mock.h'
--- tests/test-gesture-engine/ubus-server-mock.h	1970-01-01 00:00:00 +0000
+++ tests/test-gesture-engine/ubus-server-mock.h	2012-04-04 14:33:07 +0000
@@ -0,0 +1,35 @@
+/*
+ * Copyright 2012 Canonical Ltd.
+ *
+ * This program is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License version 3, as published
+ * by the  Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranties of
+ * MERCHANTABILITY, SATISFACTORY QUALITY or FITNESS FOR A PARTICULAR
+ * PURPOSE.  See the GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * version 3 along with this program.  If not, see
+ * <http://www.gnu.org/licenses/>
+ *
+ * Authored by: Daniel d'Andrada <daniel.dandrada@canonical.com>
+ *
+ */
+
+#ifndef UBUS_SERVER_MOCK_H
+#define UBUS_SERVER_MOCK_H
+
+#include <glib-object.h>
+#include <glib.h>
+
+class UBusServer {
+};
+
+UBusServer* ubus_server_get_default();
+
+void ubus_server_send_message(UBusServer*   server,
+                              const gchar*  message,
+                              GVariant*     data);
+#endif // UBUS_SERVER_MOCK_H

